==> tomcat-jakartaee-migration_0.0.2.orig.tar.xz: tomcat-jakartaee-migration-0.0.2/src/test/java/org/apache/tomcat/jakartaee/PassThroughConverterTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.tomcat.jakartaee;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;

import org.junit.Test;

import static org.junit.Assert.*;

public class PassThroughConverterTest {

    @Test
    public void testConverter() throws Exception {
        String content = "javax.servlet";

        ByteArrayInputStream in = new ByteArrayInputStream(content.getBytes());
        ByteArrayOutputStream out = new ByteArrayOutputStream();

        Converter converter = new PassThroughConverter();

        assertTrue(converter.accepts("project.properties"));

        converter.convert(in, out, null);

        assertArrayEquals(content.getBytes(), out.toByteArray());
    }
}

==> tomcat-jakartaee-migration_1.0.9.orig.tar.xz: tomcat-jakartaee-migration-1.0.9/src/test/java/org/apache/tomcat/jakartaee/PassThroughConverterTest.java <==
/*
 * Licensed to the Apache Software Foundation (ASF) under one or more
 * contributor license agreements.  See the NOTICE file distributed with
 * this work for additional information regarding copyright ownership.
 * The ASF licenses this file to You under the Apache License, Version 2.0
 * (the "License"); you may not use this file except in compliance with
 * the License.  You may obtain a copy of the License at
 *
 *      http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.apache.tomcat.jakartaee;

import java.io.ByteArrayInputStream;
import java.io.ByteArrayOutputStream;

import org.junit.Test;

import static org.junit.Assert.*;

public class PassThroughConverterTest {

    private static final String TEST_FILENAME = "project.properties";

    @Test
    public void testConverter() throws Exception {
        String content = "javax.servlet";

        ByteArrayInputStream in = new ByteArrayInputStream(content.getBytes());
        ByteArrayOutputStream out = new ByteArrayOutputStream();

        Converter converter = new PassThroughConverter();

        assertTrue(converter.accepts(TEST_FILENAME));

        converter.convert(TEST_FILENAME, in, out, null);

        assertArrayEquals(content.getBytes(), out.toByteArray());
    }
}
